"""nutri-matic Package

© All rights reserved. Jared Cook

See the LICENSE file for more details.

Author: Jared Cook
Description: Cookiecutter utilities for automating project templates.
"""

from .main import app

__all__ = [
    "app",
]
