"""nutri-matic Package

© All rights reserved. Jared Cook

See the LICENSE file for more details.

Author: Jared Cook
"""

from .cc_templates import generate_makefile, generate_readme

__all__ = [
    "generate_makefile",
    "generate_readme",
]
